//
//  ForrstAPIViewController.m
//  ForrstAPI
//
//  Created by Benjamin on 05/06/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "ForrstDemoViewController.h"

#import "FTForrstEngine.h"

@interface ForrstDemoViewController ()
- (void) showAlertViewWithError:(NSError *)error;
- (void) hideKeyboard;
@property (copy) FTResponseHandler standardResponseHandler;
@end

@implementation ForrstDemoViewController

@synthesize forrstEngine;

@synthesize activityIndicator;
@synthesize usernameTextField;
@synthesize passwordTextField;
@synthesize randomUsernameTextField;
@synthesize postIDTextField;
@synthesize postTypeTextField;
@synthesize pageTextField;
@synthesize sortTypeTextField;
@synthesize outputTextView;

@synthesize standardResponseHandler;

#pragma mark -
#pragma mark Memory Management

- (void)dealloc
{
	[forrstEngine release], forrstEngine = nil;
	
	[activityIndicator release], activityIndicator = nil;
	
	[usernameTextField release], usernameTextField = nil;
	[passwordTextField release], passwordTextField = nil;
	
	[randomUsernameTextField release], randomUsernameTextField = nil;
	[postIDTextField release], postIDTextField = nil;
	
	[postTypeTextField release], postTypeTextField = nil;
	[pageTextField release], pageTextField = nil;
	[sortTypeTextField release], sortTypeTextField = nil;
	
	[outputTextView release], outputTextView = nil;
	
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
	
    self.activityIndicator = nil;
	
	self.usernameTextField = nil;
	self.passwordTextField = nil;
	
	self.randomUsernameTextField = nil;
	self.postIDTextField = nil;
	
	self.postTypeTextField = nil;
	self.pageTextField = nil;
	self.sortTypeTextField = nil;
	
	self.outputTextView = nil;
}

#pragma mark - 
#pragma mark View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	
	if (!forrstEngine) {
		forrstEngine = [[FTForrstEngine alloc] initWithUserAgent:kUserAgent];
	}
	
	if (!standardResponseHandler) {
		self.standardResponseHandler = ^(id response, NSError *error) {
			[activityIndicator stopAnimating];
			if (!response) {
				[self showAlertViewWithError:error];
			} else {
				outputTextView.text = [response description];
			}
		};
	}
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - 
#pragma mark Instance Methods

- (IBAction) login
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *username = usernameTextField.text;
	NSString *password = passwordTextField.text;
	
	[forrstEngine loginWithUsername:username 
						   password:password 
					responseHandler:standardResponseHandler];
}

- (IBAction) loadUsageStats
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	[forrstEngine loadUsageStatsWithResponseHandler:standardResponseHandler];
}

- (IBAction) loadUserInfo
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *theUsername = randomUsernameTextField.text;
	FTUser *aUser = [[FTUser alloc] initWithUsername:theUsername];
	
	[forrstEngine loadUserInfoWithUser:aUser responseHandler:standardResponseHandler];
	[aUser release];
}

- (IBAction) loadUserPosts
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *theUsername = randomUsernameTextField.text;
	FTUser *aUser = [[FTUser alloc] initWithUsername:theUsername];
	
	[forrstEngine loadUserPostsWithUser:aUser postType:FTPostTypeAny limit:FTUserPostsLimitDefault afterPost:nil responseHandler:standardResponseHandler];
	[aUser release];
}

- (IBAction) loadPostInfo
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *thePostID = postIDTextField.text;
	FTPost *aPost = [[FTPost alloc] initWithPostID:[thePostID integerValue]];
	
	[forrstEngine loadPostInformationWithPost:aPost responseHandler:standardResponseHandler];
	[aPost release];
}

- (IBAction) loadPostsAfter
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *thePostID = postIDTextField.text;
	FTPost *aPost = nil;
	if (thePostID) {
		aPost = [[FTPost alloc] initWithPostID:[thePostID integerValue]];
	}
	
	[forrstEngine loadAllPostsAfterPost:aPost responseHandler:standardResponseHandler];
	[aPost release];
}

- (IBAction) loadPostList
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *postType = postTypeTextField.text;
	NSString *sortType = [sortTypeTextField.text length] == 0 ? nil : sortTypeTextField.text;
	NSUInteger page = [pageTextField.text integerValue] > 0 ? [pageTextField.text integerValue] : 0;
	
	[forrstEngine loadPostListWithPostsOfType:postType sortingType:sortType page:page responseHandler:standardResponseHandler];
}

- (IBAction) loadComments
{
	[self hideKeyboard];
	[activityIndicator startAnimating];
	
	NSString *thePostID = postIDTextField.text;
	FTPost *aPost = nil;
	if (thePostID) {
		aPost = [[[FTPost alloc] initWithPostID:[thePostID integerValue]] autorelease];
	}
	
	[forrstEngine loadCommentsForPost:aPost responseHandler:standardResponseHandler];
}

- (IBAction) useSSLSwitchValueChanged:(id)sender
{
	UISwitch *useSSLSwitch = (UISwitch *)sender;
	forrstEngine.useSSL = [useSSLSwitch isOn];
}

#pragma mark - 
#pragma mark Private Methods

- (void) showAlertViewWithError:(NSError *)error
{
	NSString *title = [NSString stringWithFormat:@"Domain: %@. Code: %i", error.domain, error.code];
	NSString *message = [error localizedDescription];
	
	UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:title 
														message:message 
													   delegate:nil 
											  cancelButtonTitle:@"Dismiss" 
											  otherButtonTitles:nil];
	
	[alertView show];
	[alertView release];
}

- (void) hideKeyboard
{
	if ([usernameTextField isFirstResponder])
		[usernameTextField resignFirstResponder];
	else if ([passwordTextField isFirstResponder])
		[passwordTextField resignFirstResponder];
	else if ([randomUsernameTextField isFirstResponder])
		[randomUsernameTextField resignFirstResponder];
	else if ([postIDTextField isFirstResponder])
		[postIDTextField resignFirstResponder];
	else if ([postTypeTextField isFirstResponder])
		[postTypeTextField resignFirstResponder];
	else if ([pageTextField isFirstResponder])
		[pageTextField resignFirstResponder];
	else if ([sortTypeTextField isFirstResponder])
		[sortTypeTextField resignFirstResponder];
}


@end
