//
//  FTPost.h
//  ForrstAPI
//
//  Created by Benjamin on 06/06/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "FTPhoto.h"
#import "FTUser.h"


/**********************************************
 ** FTPost Constants 
 ***********************************************/

// Typedef NSString to FTPostType for more meaningful variable naming
typedef NSString* FTPostType;

// Constants for different types of posts
extern FTPostType const FTPostTypeAny;
extern FTPostType const FTPostTypeCode;
extern FTPostType const FTPostTypeSnap;
extern FTPostType const FTPostTypeLink;
extern FTPostType const FTPostTypeQuestion;
extern FTPostType const FTPostTypeUnknown;

// Possible values for an FTPhoto representing a snap
extern NSString* const FTPostSnapPhotoSizeMega;
extern NSString* const FTPostSnapPhotoSizeKeith;
extern NSString* const FTPostSnapPhotoSizeLarge;
extern NSString* const FTPostSnapPhotoSizeMedium;
extern NSString* const FTPostSnapPhotoSizeSmall;
extern NSString* const FTPostSnapPhotoSizeThumbnail;
extern NSString* const FTPostSnapPhotoSizeOriginal;

/**********************************************
 ** FTPost Interface 
 ***********************************************/

@interface FTPost : NSObject {
	NSString *title;
	NSArray *tags;
	
	NSString *url; // Only set if type is FTPostTypeLink. Does not point to the post url.
	NSString *content;
	NSString *formattedContent;
	NSString *postDescription; // Must be prefixed with post to avoid conflict with NSObject's -description
	NSString *formattedPostDescription;
	FTPhoto *snapPhoto; 
	
	NSUInteger likesNumber;
	NSUInteger commentsNumber;
	
	NSUInteger postID;
	NSString *tinyID;
	NSString *postURL;
	FTPostType postType;
	FTUser *createdBy;
	
	NSDate *createdDate;
	NSDate *updatedDate;
	BOOL publicPost;
	BOOL publishedPost;
}

@property (copy) NSString *title;
@property (retain) NSArray *tags;

@property (copy) NSString *url; // Only set if type is FTPostTypeLink. Does not point to the post url.
@property (copy) NSString *content;
@property (copy) NSString *formattedContent;
@property (copy) NSString *postDescription; // Must be prefixed with post to avoid conflict with NSObject's -description
@property (copy) NSString *formattedPostDescription;
@property (retain) FTPhoto *snapPhoto; 

@property () NSUInteger likesNumber;
@property () NSUInteger commentsNumber;

@property () NSUInteger postID;
@property (copy) NSString *tinyID;
@property (copy) NSString *postURL;
@property (copy) FTPostType postType;
@property (retain) FTUser *createdBy;

@property (retain) NSDate *createdDate;
@property (retain) NSDate *updatedDate;
@property (getter=isPublicPost) BOOL publicPost;
@property (getter=isPublishedPost) BOOL publishedPost;

/* Makes sure aPostType is a valid post type. */
+ (BOOL) isValidPostType:(FTPostType)aPostType;

/* Used for initializing an FTPost with only the id or tinyID set. Suitable for passing into a load request in FTForrstEngine. */
- (id) initWithPostID:(NSUInteger)aPostID;
- (id) initWithTinyID:(NSString *)aTinyID;

/* The response dictionary should be the 'resp' dictionary of the data returned from the server.
 * FTPost will extract the appropriate keys and load them into the variables. */
- (id) initWithResponseDictionary:(NSDictionary *)aDictionary;
- (void) setResponseDictionary:(NSDictionary *)aDictionary;


@end
