//
//  FTPost.m
//  ForrstAPI
//
//  Created by Benjamin on 06/06/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "FTPost.h"

FTPostType const FTPostTypeAny = @"";
FTPostType const FTPostTypeCode = @"code";
FTPostType const FTPostTypeSnap = @"snap";
FTPostType const FTPostTypeLink = @"link";
FTPostType const FTPostTypeQuestion = @"question";
FTPostType const FTPostTypeUnknown = @"FTPostTypeUnknown";

NSString* const FTPostSnapPhotoSizeMega		 = @"FTPostSnapPhotoSizeMega";
NSString* const FTPostSnapPhotoSizeKeith	 = @"FTPostSnapPhotoSizeKeith";
NSString* const FTPostSnapPhotoSizeLarge	 = @"FTPostSnapPhotoSizeLarge";
NSString* const FTPostSnapPhotoSizeMedium	 = @"FTPostSnapPhotoSizeMedium";
NSString* const FTPostSnapPhotoSizeSmall	 = @"FTPostSnapPhotoSizeSmall";
NSString* const FTPostSnapPhotoSizeThumbnail = @"FTPostSnapPhotoSizeThumbnail";
NSString* const FTPostSnapPhotoSizeOriginal	 = @"FTPostSnapPhotoSizeOriginal";


/**********************************************
 ** FTPost Implementation 
 ***********************************************/
@implementation FTPost

@synthesize title;
@synthesize tags;

@synthesize url;
@synthesize content;
@synthesize formattedContent;
@synthesize postDescription;
@synthesize formattedPostDescription;
@synthesize snapPhoto;

@synthesize likesNumber;
@synthesize commentsNumber;

@synthesize postID;
@synthesize tinyID;
@synthesize postURL;
@synthesize postType;
@synthesize createdBy;

@synthesize createdDate;
@synthesize updatedDate;
@synthesize publicPost;
@synthesize publishedPost;


- (void) dealloc
{
    [title release], title = nil;
	[tags release], tags = nil;
	
    [url release], url = nil;
    [content release], content = nil;
    [formattedContent release], formattedContent = nil;
    [postDescription release], postDescription = nil;
    [formattedPostDescription release], formattedPostDescription = nil;
	[snapPhoto release], snapPhoto = nil;
	
    [tinyID release], tinyID = nil;
    [postURL release], postURL = nil;
	[postType release], postType = nil;
    [createdBy release], createdBy = nil;
	
    [createdDate release], createdDate = nil;
    [updatedDate release], updatedDate = nil;
	
	[super dealloc];
}

- (NSString *) description
{
	return [NSString stringWithFormat:@"ID: %i \n TinyID: %@ \n Title: %@", postID, tinyID, title];
}

#pragma mark -
#pragma mark Class methods

+ (BOOL) isValidPostType:(FTPostType)aPostType
{
	if (aPostType == FTPostTypeCode || 
		aPostType == FTPostTypeLink || 
		aPostType == FTPostTypeQuestion || 
		aPostType == FTPostTypeSnap) {
		return YES;
	} else {
		return NO;
	}
}

#pragma mark -
#pragma mark Initialization methods

- (id) initWithPostID:(NSUInteger)aPostID
{
	self = [super init];
	if (self)
	{
		postID = aPostID;
	}
	
	return self;
}

- (id) initWithTinyID:(NSString *)aTinyID
{
	self = [super init];
	if (self)
	{
		tinyID = [aTinyID copy];
	}
	
	return self;
}

- (id) initWithResponseDictionary:(NSDictionary *)aDictionary
{
	self = [super init];
	if (self)
	{
		[self setResponseDictionary:aDictionary];
	}
	
	return self;
}

#pragma mark -
#pragma mark Instance methods

- (void) setResponseDictionary:(NSDictionary *)aDictionary
{
	// Set the title
	self.title = [aDictionary valueForKey:@"title"];
	
	// Set the tags. Contrary to the user info, post info returns this as an array.
	self.tags = [aDictionary valueForKey:@"tags"];
	
	// Set the URL
	self.url = [aDictionary valueForKey:@"url"];
	
	// Set the content and formatted content
	self.content = [aDictionary valueForKey:@"content"];
	self.formattedContent = [aDictionary valueForKey:@"formatted_content"];
	
	// Set the description and formatted description
	self.postDescription = [aDictionary valueForKey:@"description"];
	self.formattedPostDescription = [aDictionary valueForKey:@"formatted_description"];
	
	// Set the snap photo
	NSDictionary *photoURLs = [aDictionary valueForKey:@"snaps"];
	self.snapPhoto = [[[FTPhoto alloc] initWithPhotoURLs:photoURLs] autorelease];
	
	// Set the likes number
	likesNumber = [[aDictionary valueForKey:@"like_count"] integerValue];
	
	// Set the comments number
	commentsNumber	= [[aDictionary valueForKey:@"comment_count"] integerValue];
	
	// Set the post ID
	postID = [[aDictionary valueForKey:@"id"] integerValue];
	
	// Set the tiny ID
	self.tinyID = [aDictionary valueForKey:@"tiny_id"];
	
	// Set the post URL
	self.postURL = [aDictionary valueForKey:@"post_url"];
	
	// Set the post type
	self.postType = (FTPostType)[aDictionary valueForKey:@"post_type"];
	
	// Set the created by user
	NSDictionary *userDictionary = [aDictionary valueForKey:@"user"]; 
	self.createdBy = [[[FTUser alloc] initWithResponseDictionary:userDictionary] autorelease];
	
	// Create a date formatter for the dates
	NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
	[dateFormatter setDateFormat:@"yyyy-MM-d H:m:s"];
	
	// Set the created date
	NSString *createdDateString = [aDictionary valueForKey:@"created_at"];
	self.createdDate = [dateFormatter dateFromString:createdDateString];
	
	// Set the updated date
	NSString *updatedDateString = [aDictionary valueForKey:@"updated_at"];
	self.updatedDate = [dateFormatter dateFromString:updatedDateString];
	
	// Set the public post bool
	publicPost = [[aDictionary valueForKey:@"public"] boolValue];
	
	// Set the published post bool
	publishedPost = [[aDictionary valueForKey:@"published"] boolValue];
	
	// Cleanup
	[dateFormatter release];
}

@end
