//
//  FTUser.m
//  ForrstAPI
//
//  Created by Benjamin on 05/06/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "FTUser.h"

NSString* const FTUserPhotoSizeExtraLarge	= @"xl_url";
NSString* const FTUserPhotoSizeLarge		= @"large_url";
NSString* const FTUserPhotoSizeMedium		= @"medium_url";
NSString* const FTUserPhotoSizeSmall		= @"small_url";
NSString* const FTUserPhotoSizeThumbnail	= @"thumb_url";

/**********************************************
 ** FTUser Implementation 
 ***********************************************/
@implementation FTUser

@synthesize userID;
@synthesize name;
@synthesize username;

@synthesize hasForrstMe;
@synthesize userKind;
@synthesize tags;
@synthesize htmlBio;
@synthesize homepage;
@synthesize profileURL;
@synthesize userPhoto;
@synthesize twitterUsername;

@synthesize postsNumber;
@synthesize likesNumber;
@synthesize commentsNumber;
@synthesize followersNumber;
@synthesize followingNumber;

- (void) dealloc
{
	[name release], name = nil;
	[username release], username = nil;
	
	[tags release], tags = nil;
	[htmlBio release], htmlBio = nil;
	[homepage release], homepage = nil;
	[profileURL release], profileURL = nil;
	[userPhoto release], userPhoto = nil;
	[twitterUsername release], twitterUsername = nil;
	
	[super dealloc];
}

- (NSString *) description
{
	return [NSString stringWithFormat:@"ID: %i \n username: %@ \n name: %@", userID, username, name];
}

#pragma mark -
#pragma mark Initialization methods

- (id) initWithUserID:(NSUInteger)aUserID
{
	self = [super init];
	if (self)
	{
		userID = aUserID;
	}
	
	return self;
}

- (id) initWithUsername:(NSString *)aUsername
{
	self = [super init];
	if (self)
	{
		username = [aUsername copy];
	}
	
	return self;
}

- (id) initWithResponseDictionary:(NSDictionary *)aDictionary
{
	self = [super init];
	if (self)
	{
		[self setResponseDictionary:aDictionary];
	}
	
	return self;
}

#pragma mark -
#pragma mark Instance methods

- (void) setResponseDictionary:(NSDictionary *)aDictionary
{	
	// NOTE: setters are used for objects to prevent memory leaks. This is because there is a slight chance they have been set before. 
	
	// Set the user ID
	userID = [[aDictionary valueForKey:@"id"] unsignedIntegerValue];
	
	// Set the name
	self.name = [aDictionary valueForKey:@"name"];
	
	// Set the username
	self.username = [aDictionary valueForKey:@"username"];
	
	// Set whether he/she has forrst.me
	hasForrstMe = [[aDictionary valueForKey:@"in_directory"] boolValue];
	
	// Set the user kind
	NSString *userKindString = [aDictionary valueForKey:@"is_a"];
	if ([userKindString isEqualToString:@"developer & designer"]) {
		userKind = FTUserKindDeveloperDesigner;
	} else if ([userKindString isEqualToString:@"developer"]) {
		userKind = FTUserKindDeveloper;
	} else if ([userKindString isEqualToString:@"designer"]) {
		userKind = FTUserKindDesigner;
	} else {
		userKind = FTUserKindUnknown;
	}
	
	// Set the tags
	NSString *tagsString = [aDictionary valueForKey:@"tag_string"];
	self.tags = [tagsString componentsSeparatedByString:@","];
	
	// Set the bio
	self.htmlBio = [aDictionary valueForKey:@"bio"];
	
	// Set the homepage
	self.homepage = [aDictionary valueForKey:@"homepage_url"];
	
	// Set the profile URL
	self.profileURL = [aDictionary valueForKey:@"url"];
	
	// Set twitter username
	self.twitterUsername = [aDictionary valueForKey:@"twitter"];
	
	// Set the user photo
	NSDictionary *photoURLs = [aDictionary valueForKey:@"photos"];
	self.userPhoto = [[[FTPhoto alloc] initWithPhotoURLs:photoURLs] autorelease];
	
	// Set the posts number
	postsNumber = [[aDictionary valueForKey:@"posts"] integerValue];
	
	// Set the likes number
	likesNumber = [[aDictionary valueForKey:@"likes"] integerValue];
	
	// Set the comments number
	commentsNumber = [[aDictionary valueForKey:@"comments"] integerValue];
	
	// Set the followers number
	followersNumber = [[aDictionary valueForKey:@"followers"] integerValue];
	
	// Set the following number
	followingNumber = [[aDictionary valueForKey:@"following"] integerValue];
}

@end
